ImPluginTencentWebWeb class

A web implementation of the ImPluginTencentWebPlatform of the ImPluginTencentWeb plugin.

Inheritance

Constructors

ImPluginTencentWebWeb()
Constructs a ImPluginTencentWebWeb

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() Future<void>
override
initSDK({required int sdkAppID, EventListenerConfig? eventListener}) Future<void>
override
login({required String userID, required String userSig}) Future<Map<String, dynamic>>
override
logout() Future<Map<String, dynamic>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void